==> microprofile-fault-tolerance-tck-3.0-sources.jar: org/eclipse/microprofile/fault/tolerance/tck/circuitbreaker/lifecycle/BaseCircuitBreakerOnClass.java <==
/*
 *******************************************************************************
 * Copyright (c) 2020 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/
package org.eclipse.microprofile.fault.tolerance.tck.circuitbreaker.lifecycle;

import org.eclipse.microprofile.faulttolerance.CircuitBreaker;

import javax.enterprise.context.Dependent;
import javax.enterprise.inject.Typed;

import java.io.IOException;
import java.util.concurrent.atomic.AtomicInteger;

@Dependent
@Typed(BaseCircuitBreakerOnClass.class)
@CircuitBreaker(requestVolumeThreshold = 8)
public class BaseCircuitBreakerOnClass implements CircuitBreakerLifecycleService {
    private static final AtomicInteger COUNTER = new AtomicInteger();

    private final int instanceId = COUNTER.incrementAndGet();

    @Override
    public int instanceId() {
        return instanceId;
    }

    @Override
    public void service() throws IOException {
        throw new IOException();
    }
}

==> microprofile-fault-tolerance-tck-4.1.2-sources.jar: org/eclipse/microprofile/fault/tolerance/tck/circuitbreaker/lifecycle/BaseCircuitBreakerOnClass.java <==
/*
 *******************************************************************************
 * Copyright (c) 2020 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/
package org.eclipse.microprofile.fault.tolerance.tck.circuitbreaker.lifecycle;

import java.io.IOException;
import java.util.concurrent.atomic.AtomicInteger;

import org.eclipse.microprofile.faulttolerance.CircuitBreaker;

import jakarta.enterprise.context.Dependent;
import jakarta.enterprise.inject.Typed;

@Dependent
@Typed(BaseCircuitBreakerOnClass.class)
@CircuitBreaker(requestVolumeThreshold = 8)
public class BaseCircuitBreakerOnClass implements CircuitBreakerLifecycleService {
    private static final AtomicInteger COUNTER = new AtomicInteger();

    private final int instanceId = COUNTER.incrementAndGet();

    @Override
    public int instanceId() {
        return instanceId;
    }

    @Override
    public void service() throws IOException {
        throw new IOException();
    }
}
